{#def creatibutor, search_link, role = None #}
{% set creatibutor_dict = creatibutor | to_dict %}
{% if creatibutor_dict.person_or_org.type == "personal" %}
  {% set title = _("Find more records by this person") %}
  {% set searchFacet = "syntheticFields_people" %}
{% else %}
  {% set title = _("Find more records by this organization") %}
  {% set searchFacet = "syntheticFields_organizations" %}
{% endif %}
{% set name = creatibutor_dict.person_or_org.name or 
  creatibutor_dict.person_or_org.family_name ~ ', ' ~ creatibutor_dict.person_or_org.given_name %}
{% set data = {
    "value": name,
    "title": title,
    "label": name,
    "aria": name ~ ": " ~ title,
} %}
<div role="listitem" class="item creatibutor-wrap separated">
  <div class="content">
      <SearchLink data={data}  searchFacet={searchFacet} search_link={search_link}></SearchLink>
              <CreatibutorIdentifier identifiers={creatibutor_dict.person_or_org.identifiers} creatibutorName={name} />
      {%- if role.title -%} &nbsp;({{ role.title }}){%- endif -%}
  </div>
</div>
